@@ -141,7 +141,7 @@ class Auth(object):
 
         scope = bucket
         if key is not None:
-            scope = u'{0}:{1}'.format(bucket, key)
+            scope = '{0}:{1}'.format(bucket, key)
 
         args = dict(
             scope=scope,
@@ -245,7 +245,7 @@ class QiniuMacAuth(object):
         data += "\n"
 
         if content_type and content_type != "application/octet-stream" and body:
-            data += body
+            data += body.decode(encoding='UTF-8')
 
         return '{0}:{1}'.format(self.__access_key, self.__token(data))
 
